package patterntesting.check.runtime;

public interface ExceptionFactoryMBean {

	public abstract boolean isActive();

	/**
	 * You can only provoke Exceptions if the active flag is set.
	 * @param activ
	 */
	public abstract void setActive(boolean activ);

	/**
	 * You can only provoke Exceptions if the active flag is set.
	 * Call this method to set it.
	 */
	public abstract void activate();
	
	/**
	 * If you want to provoke an Exception only for the next time use this
	 * method.
	 */
	public abstract void activateOnce();

	/**
	 * You don't want to provoke an exception any longer? Then call this
	 * method.
	 */
	public abstract void deactivate();
	
	/**
	 * To see if the (Sun) Java-VM was called with the option "-ea"
	 * ("enable asserts") this getter shows it.
	 * 
	 * @return true if asserts are enabled
	 */
	public abstract boolean isAssertsEnabled();

	/**
	 * @return the last exception which was thrown by one of the provoke methods
	 */
	public abstract Throwable getLastProvoked();

	/**
	 * Only exceptions of this returned type (or subclasses of it) are thrown.
	 * The return value is a String because of the use as MBean (works better
	 * in the JConsole).
	 * 
	 * @return the limitedTo (e.g. "java.lang.Throwable")
	 */
	public abstract String getLimitedTo();

	/**
	 * You want to limit the provoked exceptions to IOException (or subclass)?
	 * Then give it as parameter to this setter method.
	 * </br>
	 * If you want to reset it and allow all Exceptions call
	 * <tt>setLimitedTo("java.lang.Throwable")</tt>.
	 * <br>
	 * For better use with the JConsole the class could given as String.
	 * But don't forget to give the complete classname (with package) as
	 * String.
	 * 
	 * @param limitedTo e.g. "java.io.IOException"
	 */
	public abstract void setLimitedTo(String limitedTo)
			throws ClassNotFoundException;

	/**
	 * @return the number of provoked exeptions
	 */
	public abstract long getNumberOfProvoked();
	
	/**
	 * Limit the number of provoked maximal total number of provoked exceptions
	 * to n.
	 * 
	 * @param n the maximal number of provoked exceptions
     *         (default is Long.MAX_VALUE)
	 */
	public abstract void setMaxNumberOfProvoked(long n);
	
	/**
	 * @return the maximal number of provoked exceptions
	 *         (default is Long.MAX_VALUE)
	 */
	public abstract long getMaxNumberOfProvoked();
	
}
/**
 * $Log: ExceptionFactoryMBean.java,v $
 * Revision 1.3  2009/03/09 21:23:27  oboehm
 * extended the ExceptionFactory by activateOnce()
 * and other useful methods / attributes
 *
 * Revision 1.2  2009/03/08 15:47:12  oboehm
 * TestExceptionAspect splitted into an abstract and concrete part
 *
 * Revision 1.1  2009/03/08 13:58:09  oboehm
 * ExceptionFactory registers itself as MBean now
 *
 * $Source: /cvsroot/patterntesting/PatternTesting08/patterntesting-check/src/main/java/patterntesting/check/runtime/ExceptionFactoryMBean.java,v $
 */
